Hi!

Thank you very much for your submission to Ansible. It means a lot to us that you've taken the time to contribute.

Since Ansible 2.10 we are no longer accepting new modules/plugins into Ansible core.
However, we recommend looking into providing this functionality through Ansible Galaxy via Ansible Collections. You can find more information about collections at:

* <https://docs.ansible.com/ansible/devel/dev_guide/developing_collections.html>.

Because this project is very active, we're unlikely to see comments made on closed tickets and we lock them after some time.
The Ansible Forum is the best place to start a discussion about this particular issue.

See this page for a complete and up-to-date list of communication channels and their purposes:

* <https://docs.ansible.com/ansible/latest/community/communication.html>

Thank you once again for this and your interest in Ansible!
